Learn R Programming

semhelpinghands (version 0.1.14)

semhelpinghands-package: semhelpinghands: Helper Functions for Structural Equation Modeling

Description

logo

An assortment of helper functions for doing structural equation modeling, mainly by 'lavaan' for now. Most of them are time-saving functions for common tasks in doing structural equation modeling and reading the output. This package is not for functions that implement advanced statistical procedures. It is a light-weight package for simple functions that do simple tasks conveniently, with as few dependencies as possible.

Arguments

Author

Maintainer: Shu Fai Cheung shufai.cheung@gmail.com (ORCID)

See Also